@@ -1,3 +1,5 @@
+# @meta combine-shorts
+
 # @cmd All kind of options
 # @option    --oa                   
 # @option -b --ob                   short
@@ -20,7 +22,7 @@
 # @option    --ofd*,[`_choice_fn`]  multi-occurs + choice from fn + comma-separated list
 # @option    --oxa~                 capture all remaining args
 options() {
-    :;
+    _debug "$@";
 }
 
 # @cmd All kind of flags
@@ -30,7 +32,7 @@ options() {
 # @flag     --fd*        multi-occurs
 # @flag  -e --fe*        short + multi-occurs
 flags() {
-    :;
+    _debug "$@";
 }
 
 # @cmd Flags or options with single hyphen
@@ -42,16 +44,16 @@ flags() {
 # @option  -ona <PATH>
 # @option  -oca[a|b]
 # @option  -ofa[`_choice_fn`]
-single-hyphen() {
-    :;
+options-one-hyphen() {
+    _debug "$@";
 }
 
 # @cmd Value notation modifier
 # @option --oa <VALUE*>           multi values, zero or more
 # @option --ob <VALUE+>           multi values, one or more
 # @option --oc <VALUE?>           zero or one
-notation-modifier() {
-    :;
+options-notation-modifier() {
+    _debug "$@";
 }
 
 # @cmd All kind of options
@@ -75,8 +77,8 @@ notation-modifier() {
 # @option     +ofc*[`_choice_fn`]   multi-occurs + choice from fn
 # @option     +ofd*,[`_choice_fn`]  multi-occurs + choice from fn + comma-separated list
 # @option     +oxa~                 capture all remaining args
-plus-options() {
-    :;
+options-plus() {
+    _debug "$@";
 }
 
 # @cmd All kind of flags
@@ -85,23 +87,70 @@ plus-options() {
 # @flag  +c              short only
 # @flag      +fd*        multi-occurs
 # @flag  +e  +fe*        short + multi-occurs
-plus-flags() {
-    :;
+flags-plus() {
+    _debug "$@";
 }
 
 # @cmd Mixed `-` and `+` options
 # @option +a -a
 # @option -b +b
 # @option +c --c
-mix-options() {
-    :;
+options-mixed() {
+    _debug "$@";
 }
 
 # @cmd Prefixed option
 # @option -X-*[`_choice_fn`]       prefixied + multi-occurs + choice from fn
 # @option +X-*[`_choice_fn`]       prefixied + multi-occurs + choice from fn
-prefixed-option() {
-    :;
+options-prefixed() {
+    _debug "$@";
+}
+
+
+# @cmd
+# @flag   -a
+# @flag      --fa
+# @flag   -f --fb*
+# @flag      -sa
+# @flag      -sb*
+# @option -e
+# @option    --oa
+# @option    --ob*
+# @option    --oc <DIR>
+# @option -o --od <FILE> <FILE>
+# @option    --oe*,
+# @option    --ca[x|y|z]
+# @option    --cc[`_choice_fn`]
+# @option    --cd[?`_choice_fn`]
+# @option    --ce*[`_choice_fn`]
+# @option -s -soa
+test1() {
+    _debug "$@";
+}
+
+# @cmd
+# @option -a --oa!
+# @option    --ob+
+# @option    --oc+,
+# @option    --oca![`_choice_fn`]
+# @option    --ocb+[`_choice_fn`]
+# @option    --occ+,[`_choice_fn`]
+test2() {
+    _debug "$@";
+}
+
+# @cmd
+# @option    --oe=val
+# @option    --of=`_default_fn`
+# @option    --cb[=x|y|z]
+test3() {
+    _debug "$@";
+}
+
+_debug() {
+    printenv | grep ARGC_
+    ( set -o posix ; set ) | grep argc_
+    echo "$@"
 }
 
 _default_fn() {
