@@ -7,14 +7,14 @@ use self::root_data::RootData;
 use crate::argc_value::ArgcValue;
 use crate::matcher::Matcher;
 use crate::param::{FlagOptionParam, PositionalParam};
-use crate::parser::{parse, Event, EventData, EventScope, Position};
+use crate::parser::{parse, parse_symbol, Event, EventData, EventScope, Position};
 use crate::utils::INTERNAL_MODE;
 use crate::Result;
 
-use anyhow::bail;
+use anyhow::{anyhow, bail};
 use indexmap::IndexMap;
 use std::cell::RefCell;
-use std::collections::HashMap;
+use std::collections::{HashMap, HashSet};
 use std::sync::Arc;
 
 pub fn eval(
@@ -48,14 +48,15 @@ pub struct Command {
     pub(crate) names_checker: NamesChecker,
     pub(crate) root: Arc<RefCell<RootData>>,
     pub(crate) aliases: Vec<String>,
-    pub(crate) metadata: IndexMap<String, (String, Position)>,
+    pub(crate) metadata: Vec<(String, String, Position)>,
+    pub(crate) symbols: IndexMap<char, SymbolParam>,
 }
 
 impl Command {
     pub fn new(source: &str) -> Result<Self> {
         let events = parse(source)?;
         let mut root = Command::new_from_events(&events)?;
-        if root.metadata.contains_key("inherit-flag-options") {
+        if root.has_metadata("inherit-flag-options") {
             root.inherit_flag_options();
         }
         Ok(root)
@@ -102,11 +103,8 @@ impl Command {
             .collect();
         let positional_params: Vec<serde_json::Value> =
             self.positional_params.iter().map(|v| v.to_json()).collect();
-        let mut metadata = serde_json::Map::new();
-        for (k, (v, _)) in &self.metadata {
-            metadata.insert(k.to_string(), serde_json::Value::String(v.to_string()));
-        }
-        let metadata = serde_json::Value::Object(metadata);
+        let metadata: Vec<Vec<&String>> =
+            self.metadata.iter().map(|(k, v, _)| vec![k, v]).collect();
         serde_json::json!({
             "describe": self.describe,
             "name": self.name,
@@ -140,15 +138,14 @@ impl Command {
                 }
                 EventData::Meta(key, value) => {
                     let cmd = Self::get_cmd(&mut root_cmd, "@meta", position)?;
-                    if let Some((_, pos)) = cmd.metadata.get(&key) {
-                        bail!(
-                            "@meta(line {}) conflicts with '{}' at line {}",
-                            position,
-                            key,
-                            pos
-                        )
+                    if key == "symbol" {
+                        let (ch, name, choice_fn) = parse_symbol(&value).ok_or_else(|| {
+                            anyhow!("@meta(line {}) invalid symbol value", position)
+                        })?;
+                        cmd.symbols
+                            .insert(ch, (name.to_string(), choice_fn.map(|v| v.to_string())));
                     }
-                    cmd.metadata.insert(key, (value, position));
+                    cmd.metadata.push((key, value, position));
                 }
                 EventData::Cmd(value) => {
                     if root_data.borrow().scope == EventScope::CmdStart {
@@ -270,6 +267,22 @@ impl Command {
         Ok(root_cmd)
     }
 
+    pub(crate) fn has_metadata(&self, key: &str) -> bool {
+        self.metadata.iter().any(|(k, _, _)| k == key)
+    }
+
+    pub(crate) fn flag_option_signs(&self) -> String {
+        let mut signs = HashSet::new();
+        signs.insert('-');
+        for param in &self.flag_option_params {
+            if let Some(short) = &param.short {
+                signs.extend(short.chars().take(1))
+            }
+            signs.extend(param.long_prefix.chars())
+        }
+        signs.into_iter().collect()
+    }
+
     pub(crate) fn render_help(&self, cmd_paths: &[&str], term_width: Option<usize>) -> String {
         let mut output = vec![];
         if self.version.is_some() {
@@ -310,7 +323,7 @@ impl Command {
             .flag_option_params
             .iter()
             .filter(|v| v.required())
-            .map(|v| v.render_name_values())
+            .map(|v| v.render_name_notations())
             .collect();
         if self.flag_option_params.len() != required_options.len() {
             output.push("[OPTIONS]".to_string());
@@ -360,10 +373,10 @@ impl Command {
         }
         let mut list = vec![];
         let mut any_describe = false;
-        let mut single_hyphen = false;
+        let mut single = false;
         for param in self.flag_option_params.iter() {
-            if param.single_hyphen {
-                single_hyphen = true;
+            if param.long_prefix.len() == 1 {
+                single = true;
             }
             let value = param.render_body();
             let describe = param.render_describe();
@@ -372,8 +385,8 @@ impl Command {
             }
             list.push((value, describe));
         }
-        self.add_help_flag(&mut list, single_hyphen, any_describe);
-        self.add_version_flag(&mut list, single_hyphen, any_describe);
+        self.add_help_flag(&mut list, single, any_describe);
+        self.add_version_flag(&mut list, single, any_describe);
         output.push("OPTIONS:".to_string());
         let value_size = list.iter().map(|v| v.0.len()).max().unwrap_or_default() + 2;
         for (value, describe) in list {
@@ -424,7 +437,7 @@ impl Command {
     }
 
     pub(crate) fn render_subcommand_describe(&self) -> String {
-        let mut output = self.describe_head().to_string();
+        let mut output = self.describe_oneline().to_string();
         if self.aliases.is_empty() {
             return output;
         } else {
@@ -436,7 +449,7 @@ impl Command {
         output
     }
 
-    pub(crate) fn describe_head(&self) -> &str {
+    pub(crate) fn describe_oneline(&self) -> &str {
         match self.describe.split_once('\n') {
             Some((v, _)) => v,
             None => self.describe.as_str(),
@@ -470,7 +483,7 @@ impl Command {
     pub(crate) fn find_flag_option(&self, name: &str) -> Option<&FlagOptionParam> {
         self.flag_option_params
             .iter()
-            .find(|v| v.name() == name || v.is_match(name))
+            .find(|v| v.var_name() == name || v.is_match(name))
     }
 
     pub(crate) fn find_prefixed_option(&self, name: &str) -> Option<(&FlagOptionParam, String)> {
@@ -486,14 +499,14 @@ impl Command {
 
     pub(crate) fn match_version_short_name(&self) -> bool {
         match self.find_flag_option("-V") {
-            Some(param) => param.name() == "version",
+            Some(param) => param.var_name() == "version",
             None => true,
         }
     }
 
     pub(crate) fn match_help_short_name(&self) -> bool {
         match self.find_flag_option("-h") {
-            Some(param) => param.name() == "help",
+            Some(param) => param.var_name() == "help",
             None => true,
         }
     }
@@ -545,7 +558,7 @@ impl Command {
         for subcmd in self.subcommands.iter_mut() {
             let mut inherited_flag_options = vec![];
             for flag_option in &self.flag_option_params {
-                if subcmd.find_flag_option(flag_option.name()).is_none() {
+                if subcmd.find_flag_option(flag_option.var_name()).is_none() {
                     let mut flag_option = flag_option.clone();
                     flag_option.inherit = true;
                     inherited_flag_options.push(flag_option);
@@ -592,16 +605,11 @@ impl Command {
         self.subcommands.last_mut().unwrap()
     }
 
-    fn add_help_flag(
-        &self,
-        list: &mut Vec<(String, String)>,
-        single_hyphen: bool,
-        any_describe: bool,
-    ) {
+    fn add_help_flag(&self, list: &mut Vec<(String, String)>, single: bool, any_describe: bool) {
         if self.find_flag_option("help").is_some() {
             return;
         }
-        let hyphens = if single_hyphen { " -" } else { "--" };
+        let hyphens = if single { " -" } else { "--" };
         list.push((
             if self.match_help_short_name() {
                 format!("-h, {}help", hyphens)
@@ -616,19 +624,14 @@ impl Command {
         ));
     }
 
-    fn add_version_flag(
-        &self,
-        list: &mut Vec<(String, String)>,
-        single_hyphen: bool,
-        any_describe: bool,
-    ) {
+    fn add_version_flag(&self, list: &mut Vec<(String, String)>, single: bool, any_describe: bool) {
         if self.version.is_none() {
             return;
         }
         if self.find_flag_option("version").is_some() {
             return;
         }
-        let hyphens = if single_hyphen { " -" } else { "--" };
+        let hyphens = if single { " -" } else { "--" };
         list.push((
             if self.match_version_short_name() {
                 format!("-V, {}version", hyphens)
@@ -644,6 +647,8 @@ impl Command {
     }
 }
 
+pub(crate) type SymbolParam = (String, Option<String>);
+
 fn retrive_cmd<'a>(cmd: &'a mut Command, cmd_paths: &[String]) -> Option<&'a mut Command> {
     if cmd_paths.is_empty() {
         return Some(cmd);
