@@ -4,7 +4,6 @@ use crate::param::{
 use crate::utils::{is_choice_value_terminate, is_default_value_terminate};
 use crate::Result;
 use anyhow::bail;
-use nom::error::ErrorKind;
 use nom::{
     branch::alt,
     bytes::complete::{escaped, tag, take_till, take_while1},
@@ -13,6 +12,7 @@ use nom::{
         streaming::none_of,
     },
     combinator::{eof, fail, map, not, opt, peek, rest, success},
+    error::ErrorKind,
     multi::{many0, many1, separated_list1},
     sequence::{delimited, pair, preceded, separated_pair, terminated, tuple},
 };
@@ -109,6 +109,11 @@ pub(crate) fn parse(source: &str) -> Result<Vec<Event>> {
     Ok(result)
 }
 
+pub(crate) fn parse_symbol(input: &str) -> Option<(char, &str, Option<&str>)> {
+    let input = input.trim();
+    parse_symbol_data(input).map(|(_, v)| v).ok()
+}
+
 fn parse_line(line: &str) -> nom::IResult<&str, Option<Option<EventData>>> {
     alt((map(alt((parse_tag, parse_fn)), Some), success(None)))(line)
 }
@@ -217,8 +222,7 @@ fn parse_option_param(input: &str) -> nom::IResult<&str, FlagOptionParam> {
 fn parse_with_long_option_param(input: &str) -> nom::IResult<&str, FlagOptionParam> {
     map(
         tuple((
-            parse_short,
-            preceded(space0, alt((tag("--"), tag("-")))),
+            parse_with_long_head,
             alt((
                 parse_param_modifer_choices_default,
                 parse_param_modifer_choices_fn,
@@ -230,15 +234,8 @@ fn parse_with_long_option_param(input: &str) -> nom::IResult<&str, FlagOptionPar
             parse_zero_or_many_value_notations,
             parse_tail,
         )),
-        |(short, hyphens, arg, value_names, describe)| {
-            FlagOptionParam::new(
-                arg,
-                describe,
-                short,
-                false,
-                hyphens.len() == 1,
-                &value_names,
-            )
+        |((short, long_prefix), arg, value_names, describe)| {
+            FlagOptionParam::new(arg, describe, false, short, long_prefix, &value_names)
         },
     )(input)
 }
@@ -247,25 +244,23 @@ fn parse_with_long_option_param(input: &str) -> nom::IResult<&str, FlagOptionPar
 fn parse_no_long_option_param(input: &str) -> nom::IResult<&str, FlagOptionParam> {
     map(
         tuple((
+            preceded(space0, alt((tag("-"), tag("+")))),
             preceded(
-                pair(space0, tag("-")),
-                preceded(
-                    verify_single_char,
-                    alt((
-                        parse_param_modifer_choices_default,
-                        parse_param_modifer_choices_fn,
-                        parse_param_modifer_choices,
-                        parse_param_assign_fn,
-                        parse_param_assign,
-                        parse_param_modifer,
-                    )),
-                ),
+                verify_single_char,
+                alt((
+                    parse_param_modifer_choices_default,
+                    parse_param_modifer_choices_fn,
+                    parse_param_modifer_choices,
+                    parse_param_assign_fn,
+                    parse_param_assign,
+                    parse_param_modifer,
+                )),
             ),
             parse_zero_or_many_value_notations,
             parse_tail,
         )),
-        |(arg, value_names, describe)| {
-            FlagOptionParam::new(arg, describe, None, false, true, &value_names)
+        |(long_prefix, arg, value_names, describe)| {
+            FlagOptionParam::new(arg, describe, false, None, long_prefix, &value_names)
         },
     )(input)
 }
@@ -297,14 +292,9 @@ fn parse_flag_param(input: &str) -> nom::IResult<&str, FlagOptionParam> {
 // Parse `@flag`
 fn parse_with_long_flag_param(input: &str) -> nom::IResult<&str, FlagOptionParam> {
     map(
-        tuple((
-            parse_short,
-            preceded(space0, alt((tag("--"), tag("-")))),
-            parse_long_flag_and_asterisk,
-            parse_tail,
-        )),
-        |(short, hyphens, arg, describe)| {
-            FlagOptionParam::new(arg, describe, short, true, hyphens.len() == 1, &[])
+        tuple((parse_with_long_head, parse_with_long_flag_name, parse_tail)),
+        |((short, long_prefix), arg, describe)| {
+            FlagOptionParam::new(arg, describe, true, short, long_prefix, &[])
         },
     )(input)
 }
@@ -313,15 +303,18 @@ fn parse_with_long_flag_param(input: &str) -> nom::IResult<&str, FlagOptionParam
 fn parse_no_long_flag_param(input: &str) -> nom::IResult<&str, FlagOptionParam> {
     map(
         tuple((
-            preceded(pair(space0, tag("-")), parse_short_flag_and_asterisk),
+            preceded(space0, alt((tag("-"), tag("+")))),
+            parse_no_long_flag_name,
             parse_tail,
         )),
-        |(arg, describe)| FlagOptionParam::new(arg, describe, None, true, true, &[]),
+        |(long_prefix, arg, describe)| {
+            FlagOptionParam::new(arg, describe, true, None, long_prefix, &[])
+        },
     )(input)
 }
 
 // Parse `str*` `str`
-fn parse_long_flag_and_asterisk(input: &str) -> nom::IResult<&str, ParamData> {
+fn parse_with_long_flag_name(input: &str) -> nom::IResult<&str, ParamData> {
     alt((
         map(terminated(parse_param_name, tag("*")), |mut arg| {
             arg.modifer = Modifier::MultipleOptional;
@@ -331,8 +324,8 @@ fn parse_long_flag_and_asterisk(input: &str) -> nom::IResult<&str, ParamData> {
     ))(input)
 }
 
-// Parse ':' or '#' or '0'
-fn parse_short_flag_and_asterisk(input: &str) -> nom::IResult<&str, ParamData> {
+// Parse 'ch*' or 'ch`
+fn parse_no_long_flag_name(input: &str) -> nom::IResult<&str, ParamData> {
     fn parser(input: &str) -> nom::IResult<&str, ParamData> {
         map(satisfy(is_short_char), |ch| {
             ParamData::new(&format!("{}", ch))
@@ -346,6 +339,22 @@ fn parse_short_flag_and_asterisk(input: &str) -> nom::IResult<&str, ParamData> {
     })(input)
 }
 
+fn parse_with_long_head(input: &str) -> nom::IResult<&str, (Option<&str>, &str)> {
+    map(
+        alt((pair(
+            opt(terminated(
+                pair(
+                    opt(alt((char::<&str, _>('-'), char('+')))),
+                    satisfy(is_short_char),
+                ),
+                peek(space1),
+            )),
+            preceded(space0, alt((tag("--"), tag("-"), tag("+")))),
+        ),)),
+        |(short, long_prefix)| (short.map(|_| &input[0..2]), long_prefix),
+    )(input)
+}
+
 // Parse `str!` `str~` `str*` `str+` `str`
 fn parse_param_modifer(input: &str) -> nom::IResult<&str, ParamData> {
     alt((
@@ -468,12 +477,6 @@ fn parse_param_name(input: &str) -> nom::IResult<&str, ParamData> {
     map(parse_name, ParamData::new)(input)
 }
 
-// Parse `-s`
-fn parse_short(input: &str) -> nom::IResult<&str, Option<char>> {
-    let short = delimited(char('-'), satisfy(is_short_char), peek(space1));
-    opt(short)(input)
-}
-
 // Zero or many '<FOO>'
 fn parse_zero_or_many_value_notations(input: &str) -> nom::IResult<&str, Vec<&str>> {
     many0(parse_value_notation)(input)
@@ -621,6 +624,20 @@ fn parse_normal_comment(input: &str) -> nom::IResult<&str, &str> {
     ))(input)
 }
 
+fn parse_symbol_data(input: &str) -> nom::IResult<&str, (char, &str, Option<&str>)> {
+    map(
+        terminated(
+            tuple((
+                alt((char('@'), char('+'))),
+                parse_name,
+                opt(delimited(char('['), parse_value_fn, char(']'))),
+            )),
+            eof,
+        ),
+        |(symbol, name, choice_fn)| (symbol, name, choice_fn),
+    )(input)
+}
+
 fn notation_text(input: &str, balances: usize) -> nom::IResult<&str, usize> {
     let (i1, c1) = anychar(input)?;
     match c1 {
@@ -657,14 +674,32 @@ fn create_err(input: &str, kind: ErrorKind) -> nom::Err<nom::error::Error<&str>>
 }
 
 fn is_name_char(c: char) -> bool {
-    c.is_ascii_alphanumeric() || matches!(c, '_' | '-' | '.' | ':')
+    c.is_ascii_alphanumeric() || matches!(c, '_' | '-' | '.' | ':' | '@')
 }
 
 fn is_short_char(c: char) -> bool {
-    c.is_ascii()
-        && !matches!(
+    c.is_ascii_alphanumeric()
+        || matches!(
             c,
-            '-' | '\t' | '"' | '\'' | '(' | ')' | '[' | ']' | '<' | '>' | '&' | '\\' | ';' | '|'
+            '!' | '#'
+                | '$'
+                | '%'
+                | '*'
+                | '+'
+                | ','
+                | '.'
+                | '/'
+                | ':'
+                | '='
+                | '?'
+                | '@'
+                | '['
+                | ']'
+                | '^'
+                | '_'
+                | '{'
+                | '}'
+                | '~'
         )
 }
 
@@ -728,13 +763,21 @@ mod tests {
     macro_rules! assert_parse_option_arg {
         ($data:literal, $expect:literal) => {
             assert_eq!(
-                parse_option_param($data).unwrap().1.render().as_str(),
+                parse_option_param($data)
+                    .unwrap()
+                    .1
+                    .render_source()
+                    .as_str(),
                 $expect
             );
         };
         ($data:literal) => {
             assert_eq!(
-                parse_option_param($data).unwrap().1.render().as_str(),
+                parse_option_param($data)
+                    .unwrap()
+                    .1
+                    .render_source()
+                    .as_str(),
                 $data
             );
         };
@@ -742,23 +785,37 @@ mod tests {
 
     macro_rules! assert_parse_flag_arg {
         ($data:literal, $expect:literal) => {
-            assert_eq!(parse_flag_arg($data).unwrap().1.render().as_str(), $expect);
+            assert_eq!(
+                parse_flag_arg($data).unwrap().1.render_source().as_str(),
+                $expect
+            );
         };
         ($data:literal) => {
-            assert_eq!(parse_flag_param($data).unwrap().1.render().as_str(), $data);
+            assert_eq!(
+                parse_flag_param($data).unwrap().1.render_source().as_str(),
+                $data
+            );
         };
     }
 
     macro_rules! assert_parse_positional_arg {
         ($data:literal, $expect:literal) => {
             assert_eq!(
-                parse_positional_param($data).unwrap().1.render().as_str(),
+                parse_positional_param($data)
+                    .unwrap()
+                    .1
+                    .render_source()
+                    .as_str(),
                 $expect
             );
         };
         ($data:literal) => {
             assert_eq!(
-                parse_positional_param($data).unwrap().1.render().as_str(),
+                parse_positional_param($data)
+                    .unwrap()
+                    .1
+                    .render_source()
+                    .as_str(),
                 $data
             );
         };
@@ -885,6 +942,25 @@ mod tests {
         assert_parse_flag_arg!("-f*");
     }
 
+    #[test]
+    fn test_parse_with_long_head() {
+        assert_eq!(
+            parse_with_long_head("-f --foo"),
+            Ok(("foo", (Some("-f"), "--")))
+        );
+        assert_eq!(
+            parse_with_long_head("-f -foo"),
+            Ok(("foo", (Some("-f"), "-")))
+        );
+        assert_eq!(parse_with_long_head("--foo"), Ok(("foo", (None, "--"))));
+        assert_eq!(parse_with_long_head("-foo"), Ok(("foo", (None, "-"))));
+        assert_eq!(
+            parse_with_long_head("+f +foo"),
+            Ok(("foo", (Some("+f"), "+")))
+        );
+        assert_eq!(parse_with_long_head("+foo"), Ok(("foo", (None, "+"))));
+    }
+
     #[test]
     fn test_parse_positional_arg() {
         assert_parse_positional_arg!("foo <FOO> A foo arg");
@@ -949,4 +1025,16 @@ mod tests {
         assert_token!("foo=bar", Ignore);
         assert_token!("#!/bin/bash", Ignore);
     }
+
+    #[test]
+    fn test_parse_symbol() {
+        assert_eq!(
+            parse_symbol("+toolchain").unwrap(),
+            ('+', "toolchain", None)
+        );
+        assert_eq!(
+            parse_symbol("+toolchain[`_choice_toolchain`]").unwrap(),
+            ('+', "toolchain", Some("_choice_toolchain"))
+        );
+    }
 }
